==> ejc-sddjsorg-impl-3.0.0-20211026.030659-77-sources.jar: com/ejianc/business/production/bean/ProductionOrgEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.production.bean.ProductionOrgEntity;
/**
 * 产权登记生成的公司信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_org")
public class ProductionOrgEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;


    @TableField(value="code")
    private java.lang.String code; // 登记单号
    @TableField(value="name")
    private String name; // 名称
    @TableField(value="unified_social_credit_code")
    private String unifiedSocialCreditCode; // 统一社会信用代码
    @TableField(value="in_reacrd")
    private Boolean inReacrd; // 是否在集团备案
    @TableField(value="out_capital_org")
    private Long outCapitalOrg; // 国家出资企业id
    @TableField(value="out_capital_org_name")
    private String outCapitalOrgName; // 国家出资企业名称
    @TableField(value="relation_to_out_org")
    private Long relationToOutOrg; // 与国家出资企业的关系id
    @TableField(value="relation_to_out_org_name")
    private String relationToOutOrgName; // 与国家出资企业的关系名称
    @TableField(value="be_owner")
    private Boolean beOwner; // 是否国家出资企业业主
    @TableField(value="main_capital_org_id")
    private Long mainCapitalOrgId; // 主要出资人id
    @TableField(value="main_capital_org_name")
    private String mainCapitalOrgName; // 主要出资人名称
    @TableField(value="register_country_id")
    private Long registerCountryId; // 注册国家id
    @TableField(value="register_country_name")
    private String registerCountryName; // 注册国家名称
    @TableField(value="register_in")
    private String registerIn; // 注册地境内/境外
    @TableField(value="register_address")
    private String registerAddress; // 注册地
    @TableField(value="register_date")
    private java.util.Date registerDate; // 注册日期
    @TableField(value="register_capital")
    private java.math.BigDecimal registerCapital; // 注册资本
    @TableField(value="currency_type_id")
    private Long currencyTypeId; // 注册资本币种id
    @TableField(value="currency_type_name")
    private String currencyTypeName; // 注册资本币种名称
    @TableField(value="register_capital_big")
    private String registerCapitalBig; // 注册资本大写
    @TableField(value="org_type_id")
    private Long orgTypeId; // 企业类别id
    @TableField(value="org_type_name")
    private String orgTypeName; // 企业类别名称
    @TableField(value="regulatory_bodies_id")
    private Long regulatoryBodiesId; // 国资监管机构id
    @TableField(value="regulatory_bodies")
    private String regulatoryBodies; // 国资监管机构
    @TableField(value="org_form_id")
    private Long orgFormId; // 组织形式
    @TableField(value="org_form_name")
    private String orgFormName; // 组织形式
    @TableField(value="major_industries_id")
    private Long majorIndustriesId; // 主要行业
    @TableField(value="major_industries")
    private String majorIndustries; // 主要行业
    @TableField(value="product_level")
    private String productLevel; // 企业产权级次
    @TableField(value="manger_level")
    private String mangerLevel; // 企业管理级次
    @TableField(value="merge_table")
    private Boolean mergeTable; // 是否并表
    @TableField(value="be_listed")
    private Boolean beListed; // 是否上市公司
    @TableField(value="be_closed")
    private Boolean beClosed; // 是否存在休眠/停业/歇业等情况
    @TableField(value="production_id")
    private Long productionId; // 产权登记单id
    @TableField(value="org_id")
    private Long orgId;
    @TableField(value="use_status")
    private Boolean useStatus;

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    /**
     * 名称
     */
    public String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 统一社会信用代码
     */
    public String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnifiedSocialCreditCode(String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 是否在集团备案
     */
    public Boolean getInReacrd() {
        return inReacrd;
    }

    public void setInReacrd(Boolean inReacrd) {
        this.inReacrd = inReacrd;
    }

    /**
     * 国家出资企业id
     */
    public Long getOutCapitalOrg() {
        return outCapitalOrg;
    }

    /**
     * 国家出资企业id
     */
    public void setOutCapitalOrg(Long outCapitalOrg) {
        this.outCapitalOrg = outCapitalOrg;
    }
    /**
     * 国家出资企业名称
     */
    public String getOutCapitalOrgName() {
        return outCapitalOrgName;
    }

    /**
     * 国家出资企业名称
     */
    public void setOutCapitalOrgName(String outCapitalOrgName) {
        this.outCapitalOrgName = outCapitalOrgName;
    }
    /**
     * 与国家出资企业的关系id
     */
    public Long getRelationToOutOrg() {
        return relationToOutOrg;
    }

    /**
     * 与国家出资企业的关系id
     */
    public void setRelationToOutOrg(Long relationToOutOrg) {
        this.relationToOutOrg = relationToOutOrg;
    }
    /**
     * 与国家出资企业的关系名称
     */
    public String getRelationToOutOrgName() {
        return relationToOutOrgName;
    }

    /**
     * 与国家出资企业的关系名称
     */
    public void setRelationToOutOrgName(String relationToOutOrgName) {
        this.relationToOutOrgName = relationToOutOrgName;
    }
    /**
     * 是否国家出资企业业主
     */
    public Boolean getBeOwner() {
        return beOwner;
    }

    public void setBeOwner(Boolean beOwner) {
        this.beOwner = beOwner;
    }

    /**
     * 主要出资人id
     */
    public Long getMainCapitalOrgId() {
        return mainCapitalOrgId;
    }

    /**
     * 主要出资人id
     */
    public void setMainCapitalOrgId(Long mainCapitalOrgId) {
        this.mainCapitalOrgId = mainCapitalOrgId;
    }
    /**
     * 主要出资人名称
     */
    public String getMainCapitalOrgName() {
        return mainCapitalOrgName;
    }

    /**
     * 主要出资人名称
     */
    public void setMainCapitalOrgName(String mainCapitalOrgName) {
        this.mainCapitalOrgName = mainCapitalOrgName;
    }
    /**
     * 注册国家id
     */
    public Long getRegisterCountryId() {
        return registerCountryId;
    }

    /**
     * 注册国家id
     */
    public void setRegisterCountryId(Long registerCountryId) {
        this.registerCountryId = registerCountryId;
    }
    /**
     * 注册国家名称
     */
    public String getRegisterCountryName() {
        return registerCountryName;
    }

    /**
     * 注册国家名称
     */
    public void setRegisterCountryName(String registerCountryName) {
        this.registerCountryName = registerCountryName;
    }
    /**
     * 注册地境内/境外
     */
    public String getRegisterIn() {
        return registerIn;
    }

    /**
     * 注册地境内/境外
     */
    public void setRegisterIn(String registerIn) {
        this.registerIn = registerIn;
    }
    /**
     * 注册地
     */
    public String getRegisterAddress() {
        return registerAddress;
    }

    /**
     * 注册地
     */
    public void setRegisterAddress(String registerAddress) {
        this.registerAddress = registerAddress;
    }
    /**
     * 注册日期
     */
    public java.util.Date getRegisterDate() {
        return registerDate;
    }

    /**
     * 注册日期
     */
    public void setRegisterDate(java.util.Date registerDate) {
        this.registerDate = registerDate;
    }
    /**
     * 注册资本
     */
    public java.math.BigDecimal getRegisterCapital() {
        return registerCapital;
    }

    /**
     * 注册资本
     */
    public void setRegisterCapital(java.math.BigDecimal registerCapital) {
        this.registerCapital = registerCapital;
    }
    /**
     * 注册资本币种id
     */
    public Long getCurrencyTypeId() {
        return currencyTypeId;
    }

    /**
     * 注册资本币种id
     */
    public void setCurrencyTypeId(Long currencyTypeId) {
        this.currencyTypeId = currencyTypeId;
    }
    /**
     * 注册资本币种名称
     */
    public String getCurrencyTypeName() {
        return currencyTypeName;
    }

    /**
     * 注册资本币种名称
     */
    public void setCurrencyTypeName(String currencyTypeName) {
        this.currencyTypeName = currencyTypeName;
    }
    /**
     * 注册资本大写
     */
    public String getRegisterCapitalBig() {
        return registerCapitalBig;
    }

    /**
     * 注册资本大写
     */
    public void setRegisterCapitalBig(String registerCapitalBig) {
        this.registerCapitalBig = registerCapitalBig;
    }
    /**
     * 企业类别id
     */
    public Long getOrgTypeId() {
        return orgTypeId;
    }

    /**
     * 企业类别id
     */
    public void setOrgTypeId(Long orgTypeId) {
        this.orgTypeId = orgTypeId;
    }
    /**
     * 企业类别名称
     */
    public String getOrgTypeName() {
        return orgTypeName;
    }

    /**
     * 企业类别名称
     */
    public void setOrgTypeName(String orgTypeName) {
        this.orgTypeName = orgTypeName;
    }
    /**
     * 国资监管机构id
     */
    public Long getRegulatoryBodiesId() {
        return regulatoryBodiesId;
    }

    /**
     * 国资监管机构id
     */
    public void setRegulatoryBodiesId(Long regulatoryBodiesId) {
        this.regulatoryBodiesId = regulatoryBodiesId;
    }
    /**
     * 国资监管机构
     */
    public String getRegulatoryBodies() {
        return regulatoryBodies;
    }

    /**
     * 国资监管机构
     */
    public void setRegulatoryBodies(String regulatoryBodies) {
        this.regulatoryBodies = regulatoryBodies;
    }
    /**
     * 组织形式
     */
    public Long getOrgFormId() {
        return orgFormId;
    }

    /**
     * 组织形式
     */
    public void setOrgFormId(Long orgFormId) {
        this.orgFormId = orgFormId;
    }
    /**
     * 组织形式
     */
    public String getOrgFormName() {
        return orgFormName;
    }

    /**
     * 组织形式
     */
    public void setOrgFormName(String orgFormName) {
        this.orgFormName = orgFormName;
    }
    /**
     * 主要行业
     */
    public Long getMajorIndustriesId() {
        return majorIndustriesId;
    }

    public void setMajorIndustriesId(Long majorIndustriesId) {
        this.majorIndustriesId = majorIndustriesId;
    }

    /**
     * 主要行业
     */
    public String getMajorIndustries() {
        return majorIndustries;
    }

    /**
     * 主要行业
     */
    public void setMajorIndustries(String majorIndustries) {
        this.majorIndustries = majorIndustries;
    }
    /**
     * 企业产权级次
     */
    public String getProductLevel() {
        return productLevel;
    }

    /**
     * 企业产权级次
     */
    public void setProductLevel(String productLevel) {
        this.productLevel = productLevel;
    }
    /**
     * 企业管理级次
     */
    public String getMangerLevel() {
        return mangerLevel;
    }

    /**
     * 企业管理级次
     */
    public void setMangerLevel(String mangerLevel) {
        this.mangerLevel = mangerLevel;
    }
    /**
     * 是否并表
     */
    public Boolean getMergeTable() {
        return mergeTable;
    }

    public void setMergeTable(Boolean mergeTable) {
        this.mergeTable = mergeTable;
    }

    /**
     * 是否上市公司
     */
    public Boolean getBeListed() {
        return beListed;
    }

    public void setBeListed(Boolean beListed) {
        this.beListed = beListed;
    }

    /**
     * 是否存在休眠/停业/歇业等情况
     */
    public Boolean getBeClosed() {
        return beClosed;
    }

    public void setBeClosed(Boolean beClosed) {
        this.beClosed = beClosed;
    }

    /**
     * 产权登记单id
     */
    public Long getProductionId() {
        return productionId;
    }

    /**
     * 产权登记单id
     */
    public void setProductionId(Long productionId) {
        this.productionId = productionId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Boolean getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(Boolean useStatus) {
        this.useStatus = useStatus;
    }
}

==> ejc-sddjsorg-impl-3.0.0-20211102.124754-128-sources.jar: com/ejianc/business/production/bean/ProductionOrgEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.production.bean.ProductionOrgEntity;
/**
 * 产权登记生成的公司信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_org")
public class ProductionOrgEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;


    @TableField(value="code")
    private java.lang.String code; // 登记单号
    @TableField(value="name")
    private String name; // 名称
    @TableField(value="unified_social_credit_code")
    private String unifiedSocialCreditCode; // 统一社会信用代码
    @TableField(value="in_reacrd")
    private Boolean inReacrd; // 是否在集团备案
    @TableField(value="out_capital_org")
    private Long outCapitalOrg; // 国家出资企业id
    @TableField(value="out_capital_org_name")
    private String outCapitalOrgName; // 国家出资企业名称
    @TableField(value="relation_to_out_org")
    private Long relationToOutOrg; // 与国家出资企业的关系id
    @TableField(value="relation_to_out_org_name")
    private String relationToOutOrgName; // 与国家出资企业的关系名称
    @TableField(value="be_owner")
    private Boolean beOwner; // 是否国家出资企业业主
    @TableField(value="main_capital_org_id")
    private Long mainCapitalOrgId; // 主要出资人id
    @TableField(value="main_capital_org_name")
    private String mainCapitalOrgName; // 主要出资人名称
    @TableField(value="register_country_id")
    private Long registerCountryId; // 注册国家id
    @TableField(value="register_country_name")
    private String registerCountryName; // 注册国家名称
    @TableField(value="register_in")
    private String registerIn; // 注册地境内/境外
    @TableField(value="register_address")
    private String registerAddress; // 注册地
    @TableField(value="register_date")
    private java.util.Date registerDate; // 注册日期
    @TableField(value="register_capital")
    private java.math.BigDecimal registerCapital; // 注册资本
    @TableField(value="currency_type_id")
    private Long currencyTypeId; // 注册资本币种id
    @TableField(value="currency_type_name")
    private String currencyTypeName; // 注册资本币种名称
    @TableField(value="register_capital_big")
    private String registerCapitalBig; // 注册资本大写
    @TableField(value="org_type_id")
    private Long orgTypeId; // 企业类别id
    @TableField(value="org_type_name")
    private String orgTypeName; // 企业类别名称
    @TableField(value="regulatory_bodies_id")
    private Long regulatoryBodiesId; // 国资监管机构id
    @TableField(value="regulatory_bodies")
    private String regulatoryBodies; // 国资监管机构
    @TableField(value="org_form_id")
    private Long orgFormId; // 组织形式
    @TableField(value="org_form_name")
    private String orgFormName; // 组织形式
    @TableField(value="major_industries_id")
    private String majorIndustriesId; // 主要行业
    @TableField(value="major_industries")
    private String majorIndustries; // 主要行业
    @TableField(value="product_level")
    private String productLevel; // 企业产权级次
    @TableField(value="manger_level")
    private String mangerLevel; // 企业管理级次
    @TableField(value="merge_table")
    private Boolean mergeTable; // 是否并表
    @TableField(value="be_listed")
    private Boolean beListed; // 是否上市公司
    @TableField(value="be_closed")
    private Boolean beClosed; // 是否存在休眠/停业/歇业等情况
    @TableField(value="production_id")
    private Long productionId; // 产权登记单id
    @TableField(value="org_id")
    private Long orgId;
    @TableField(value="use_status")
    private Boolean useStatus;

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    /**
     * 名称
     */
    public String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 统一社会信用代码
     */
    public String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnifiedSocialCreditCode(String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 是否在集团备案
     */
    public Boolean getInReacrd() {
        return inReacrd;
    }

    public void setInReacrd(Boolean inReacrd) {
        this.inReacrd = inReacrd;
    }

    /**
     * 国家出资企业id
     */
    public Long getOutCapitalOrg() {
        return outCapitalOrg;
    }

    /**
     * 国家出资企业id
     */
    public void setOutCapitalOrg(Long outCapitalOrg) {
        this.outCapitalOrg = outCapitalOrg;
    }
    /**
     * 国家出资企业名称
     */
    public String getOutCapitalOrgName() {
        return outCapitalOrgName;
    }

    /**
     * 国家出资企业名称
     */
    public void setOutCapitalOrgName(String outCapitalOrgName) {
        this.outCapitalOrgName = outCapitalOrgName;
    }
    /**
     * 与国家出资企业的关系id
     */
    public Long getRelationToOutOrg() {
        return relationToOutOrg;
    }

    /**
     * 与国家出资企业的关系id
     */
    public void setRelationToOutOrg(Long relationToOutOrg) {
        this.relationToOutOrg = relationToOutOrg;
    }
    /**
     * 与国家出资企业的关系名称
     */
    public String getRelationToOutOrgName() {
        return relationToOutOrgName;
    }

    /**
     * 与国家出资企业的关系名称
     */
    public void setRelationToOutOrgName(String relationToOutOrgName) {
        this.relationToOutOrgName = relationToOutOrgName;
    }
    /**
     * 是否国家出资企业业主
     */
    public Boolean getBeOwner() {
        return beOwner;
    }

    public void setBeOwner(Boolean beOwner) {
        this.beOwner = beOwner;
    }

    /**
     * 主要出资人id
     */
    public Long getMainCapitalOrgId() {
        return mainCapitalOrgId;
    }

    /**
     * 主要出资人id
     */
    public void setMainCapitalOrgId(Long mainCapitalOrgId) {
        this.mainCapitalOrgId = mainCapitalOrgId;
    }
    /**
     * 主要出资人名称
     */
    public String getMainCapitalOrgName() {
        return mainCapitalOrgName;
    }

    /**
     * 主要出资人名称
     */
    public void setMainCapitalOrgName(String mainCapitalOrgName) {
        this.mainCapitalOrgName = mainCapitalOrgName;
    }
    /**
     * 注册国家id
     */
    public Long getRegisterCountryId() {
        return registerCountryId;
    }

    /**
     * 注册国家id
     */
    public void setRegisterCountryId(Long registerCountryId) {
        this.registerCountryId = registerCountryId;
    }
    /**
     * 注册国家名称
     */
    public String getRegisterCountryName() {
        return registerCountryName;
    }

    /**
     * 注册国家名称
     */
    public void setRegisterCountryName(String registerCountryName) {
        this.registerCountryName = registerCountryName;
    }
    /**
     * 注册地境内/境外
     */
    public String getRegisterIn() {
        return registerIn;
    }

    /**
     * 注册地境内/境外
     */
    public void setRegisterIn(String registerIn) {
        this.registerIn = registerIn;
    }
    /**
     * 注册地
     */
    public String getRegisterAddress() {
        return registerAddress;
    }

    /**
     * 注册地
     */
    public void setRegisterAddress(String registerAddress) {
        this.registerAddress = registerAddress;
    }
    /**
     * 注册日期
     */
    public java.util.Date getRegisterDate() {
        return registerDate;
    }

    /**
     * 注册日期
     */
    public void setRegisterDate(java.util.Date registerDate) {
        this.registerDate = registerDate;
    }
    /**
     * 注册资本
     */
    public java.math.BigDecimal getRegisterCapital() {
        return registerCapital;
    }

    /**
     * 注册资本
     */
    public void setRegisterCapital(java.math.BigDecimal registerCapital) {
        this.registerCapital = registerCapital;
    }
    /**
     * 注册资本币种id
     */
    public Long getCurrencyTypeId() {
        return currencyTypeId;
    }

    /**
     * 注册资本币种id
     */
    public void setCurrencyTypeId(Long currencyTypeId) {
        this.currencyTypeId = currencyTypeId;
    }
    /**
     * 注册资本币种名称
     */
    public String getCurrencyTypeName() {
        return currencyTypeName;
    }

    /**
     * 注册资本币种名称
     */
    public void setCurrencyTypeName(String currencyTypeName) {
        this.currencyTypeName = currencyTypeName;
    }
    /**
     * 注册资本大写
     */
    public String getRegisterCapitalBig() {
        return registerCapitalBig;
    }

    /**
     * 注册资本大写
     */
    public void setRegisterCapitalBig(String registerCapitalBig) {
        this.registerCapitalBig = registerCapitalBig;
    }
    /**
     * 企业类别id
     */
    public Long getOrgTypeId() {
        return orgTypeId;
    }

    /**
     * 企业类别id
     */
    public void setOrgTypeId(Long orgTypeId) {
        this.orgTypeId = orgTypeId;
    }
    /**
     * 企业类别名称
     */
    public String getOrgTypeName() {
        return orgTypeName;
    }

    /**
     * 企业类别名称
     */
    public void setOrgTypeName(String orgTypeName) {
        this.orgTypeName = orgTypeName;
    }
    /**
     * 国资监管机构id
     */
    public Long getRegulatoryBodiesId() {
        return regulatoryBodiesId;
    }

    /**
     * 国资监管机构id
     */
    public void setRegulatoryBodiesId(Long regulatoryBodiesId) {
        this.regulatoryBodiesId = regulatoryBodiesId;
    }
    /**
     * 国资监管机构
     */
    public String getRegulatoryBodies() {
        return regulatoryBodies;
    }

    /**
     * 国资监管机构
     */
    public void setRegulatoryBodies(String regulatoryBodies) {
        this.regulatoryBodies = regulatoryBodies;
    }
    /**
     * 组织形式
     */
    public Long getOrgFormId() {
        return orgFormId;
    }

    /**
     * 组织形式
     */
    public void setOrgFormId(Long orgFormId) {
        this.orgFormId = orgFormId;
    }
    /**
     * 组织形式
     */
    public String getOrgFormName() {
        return orgFormName;
    }

    /**
     * 组织形式
     */
    public void setOrgFormName(String orgFormName) {
        this.orgFormName = orgFormName;
    }
    /**
     * 主要行业
     */
    public String getMajorIndustriesId() {
        return majorIndustriesId;
    }

    public void setMajorIndustriesId(String majorIndustriesId) {
        this.majorIndustriesId = majorIndustriesId;
    }

    /**
     * 主要行业
     */
    public String getMajorIndustries() {
        return majorIndustries;
    }

    /**
     * 主要行业
     */
    public void setMajorIndustries(String majorIndustries) {
        this.majorIndustries = majorIndustries;
    }
    /**
     * 企业产权级次
     */
    public String getProductLevel() {
        return productLevel;
    }

    /**
     * 企业产权级次
     */
    public void setProductLevel(String productLevel) {
        this.productLevel = productLevel;
    }
    /**
     * 企业管理级次
     */
    public String getMangerLevel() {
        return mangerLevel;
    }

    /**
     * 企业管理级次
     */
    public void setMangerLevel(String mangerLevel) {
        this.mangerLevel = mangerLevel;
    }
    /**
     * 是否并表
     */
    public Boolean getMergeTable() {
        return mergeTable;
    }

    public void setMergeTable(Boolean mergeTable) {
        this.mergeTable = mergeTable;
    }

    /**
     * 是否上市公司
     */
    public Boolean getBeListed() {
        return beListed;
    }

    public void setBeListed(Boolean beListed) {
        this.beListed = beListed;
    }

    /**
     * 是否存在休眠/停业/歇业等情况
     */
    public Boolean getBeClosed() {
        return beClosed;
    }

    public void setBeClosed(Boolean beClosed) {
        this.beClosed = beClosed;
    }

    /**
     * 产权登记单id
     */
    public Long getProductionId() {
        return productionId;
    }

    /**
     * 产权登记单id
     */
    public void setProductionId(Long productionId) {
        this.productionId = productionId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Boolean getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(Boolean useStatus) {
        this.useStatus = useStatus;
    }
}
